# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/btravel/studio/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/btravel/studio/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Btravel\\Studio\\": "packages/btravel/studio/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Btravel\Studio\Providers\StudioServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Studio'  => Btravel\Studio\Facades\Studio::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Btravel\\StudioTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Btravel\Studio\Providers\StudioServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Btravel\Studio\Providers\StudioServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Btravel\Studio\Providers\StudioServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/studio/{modulename}

**User**

    http://path-to-route-folder/user/studio/{modulename}

**Public**

    http://path-to-route-folder/studios


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/studio/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/studio/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/studio/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/studio/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/studio/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/studio/{modulename}/{slug}
    METHOD: GET