<?php

namespace Btravel\Studio\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Studio\Models\Studious;

class StudiousPolicy
{

    /**
     * Determine if the given user can view the studious.
     *
     * @param UserPolicy $user
     * @param Studious $studious
     *
     * @return bool
     */
    public function view(UserPolicy $user, Studious $studious)
    {
        if ($user->canDo('studio.studious.view') && $user->isAdmin()) {
            return true;
        }

        return $studious->user_id == user_id() && $studious->user_type == user_type();
    }

    /**
     * Determine if the given user can create a studious.
     *
     * @param UserPolicy $user
     * @param Studious $studious
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('studio.studious.create');
    }

    /**
     * Determine if the given user can update the given studious.
     *
     * @param UserPolicy $user
     * @param Studious $studious
     *
     * @return bool
     */
    public function update(UserPolicy $user, Studious $studious)
    {
        if ($user->canDo('studio.studious.edit') && $user->isAdmin()) {
            return true;
        }

        return $studious->user_id == user_id() && $studious->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given studious.
     *
     * @param UserPolicy $user
     * @param Studious $studious
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Studious $studious)
    {
        return $studious->user_id == user_id() && $studious->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given studious.
     *
     * @param UserPolicy $user
     * @param Studious $studious
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Studious $studious)
    {
        if ($user->canDo('studio.studious.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given studious.
     *
     * @param UserPolicy $user
     * @param Studious $studious
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Studious $studious)
    {
        if ($user->canDo('studio.studious.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
